@@ -2,7 +2,10 @@
 {
     require(utils)
     cat("\n",paste("ChainLadder version", packageDescription("ChainLadder")$Version,
-                   "by:\nMarkus Gesmann <markus.gesmann@gmail.com>,\nWayne (Yanwei) Zhang <actuaryzhang@uchicago.edu>\n\n"),
+                   "by:\nMarkus Gesmann <markus.gesmann@gmail.com>",
+                   "\nWayne (Yanwei) Zhang <actuaryzhang@uchicago.edu>",
+                   "\nDaniel Murphy <danielmarkmurphy@gmail.com>",
+                   "\n\n"),
         "Type library(help='ChainLadder') or ?ChainLadder\n",
         "to see overall documentation.\n\n",
         "Type demo(ChainLadder) to get an idea of the functionality of this package.\n\n",
